.. Combinatorial peptide pooling documentation master file, created by
   sphinx-quickstart on Mon Oct  9 18:14:27 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   
==============
copepodTCR
==============

CopepodTCR (COmbinatorial PEptide POoling Design for TCR specificity) is a Python tool developed for providing peptide pooling schemes for T cell specificity assays. You can access the tool via Python, the command line, or a web application.

For insight into the method and algorithm, see the **Introduction** page.

For installation guidance, visit the **Installation** page.

Begin with the package by exploring the **Quickstart** section on the **Usage** page. For a deeper understanding, we advise the **More detailed quickstart** section. The Usage page also lists the function reference.

CopepodTCR was developed at CSHL.

.. toctree::
   :maxdepth: 2
   :caption: CopepodTCR

   Introduction
   Installation
   Usage
   ShinyApp